pub struct CircuitBuildingContext {
node_id: AtomicUsize,
input_layer_id: AtomicUsize,
layer_id: AtomicUsize,
fiat_shamir_challenge_layer_id: AtomicUsize,
}Expand description
CircuitBuildingContext keeps track of the ids of the nodes and layers that are created. Contains a consistently incrementing counters to prevent id collisions.
Fields
node_id: AtomicUsizeinput_layer_id: AtomicUsizelayer_id: AtomicUsizefiat_shamir_challenge_layer_id: AtomicUsizeImplementations
Sourceimpl CircuitBuildingContext
impl CircuitBuildingContext
Sourcepub fn next_node_id() -> usize
pub fn next_node_id() -> usize
Retrieves a new node id that is guaranteed to be unique.
Sourcepub fn next_input_layer_id() -> usize
pub fn next_input_layer_id() -> usize
Retrieves a new input layer id that is guaranteed to be unique.
Sourcepub fn next_layer_id() -> usize
pub fn next_layer_id() -> usize
Retrieves a new layer id that is guaranteed to be unique.
Sourcepub fn next_fiat_shamir_challenge_layer_id() -> usize
pub fn next_fiat_shamir_challenge_layer_id() -> usize
Retrieves a new fiat shamir challenge layer id that is guaranteed to be unique.